from aws_mfa_util.util import make_credential_str_list, convert_aws_credential


def test_make_credential_str_list():
    print('hello')
    # with open('./sample_credentials', mode='r') as fd:
    #     print('OK')
    # tmp = make_credential_str_list('./sample_credentials')
    # print(tmp)
    assert True
